@@ -1,6 +1,6 @@
 package Net::Docker;
 use strict;
-our $VERSION = '0.001001';
+our $VERSION = '0.002000';
 
 use Moo;
 use JSON;
@@ -8,6 +8,9 @@ use URI;
 use URI::QueryParam;
 use LWP::UserAgent;
 use Carp;
+use AnyEvent;
+use AnyEvent::HTTP;
+use Data::Dumper;
 
 has address => (is => 'ro', default => 'http://127.0.0.1:4243');
 has ua      => (is => 'lazy');
@@ -17,7 +20,9 @@ sub _build_ua {
     return $ua;
 }
 
-sub _uri {
+sub _uri { my $self = shift; return $self->uri(@_); }
+
+sub uri {
     my ($self, $rel, %options) = @_;
     my $uri = URI->new($self->address . $rel);
     $uri->query_form(%options);
@@ -38,8 +43,6 @@ sub _parse {
 sub _parse_request {
     my ($self, $res) = @_;
     if ($res->content_type eq 'application/json') {
-        #my @lines = split/\n/, $res->decoded_content;
-        #return map { decode_json($_) } @lines;
         my $json = JSON::XS->new;
         return $json->incr_parse($res->decoded_content);
     }
@@ -48,6 +51,22 @@ sub _parse_request {
     croak $message;
 }
 
+sub create {
+    my ($self, %options) = @_;
+    $options{AttachStderr} //= \1;
+    $options{AttachStdout} //= \1;
+    $options{AttachStdin}  //= \0;
+    $options{OpenStdin}  //= \0;
+    $options{Tty} = \1;
+    my $input = encode_json(\%options);
+
+    my $res = $self->ua->post($self->uri('/containers/create'), 'Content-Type' => 'application/json', Content => $input);
+
+    my $json = JSON::XS->new;
+    my $out = $json->incr_parse($res->decoded_content);
+    return $out->{Id};
+}
+
 sub ps {
     my ($self, %options) = @_;
     return $self->_parse('/containers/ps', %options);
@@ -150,7 +169,7 @@ sub stop {
 sub logs {
     my ($self, $container) = @_;
     my %params = (
-        logs => 1,
+        logs   => 1,
         stdout => 1,
         stderr => 1,
     );
@@ -159,12 +178,64 @@ sub logs {
     return $res->content;
 }
 
+sub streaming_logs {
+    my $cb = pop @_; # last argument is the callback
+
+    my ($self, $container, %options) = @_;
+
+    if (ref($cb) ne 'CODE') {
+        croak "Callback is not a code ref";
+    }
+
+    my $uri = $self->uri('/containers/'.$container.'/attach', %options);
+
+    my $cv = AnyEvent->condvar;
+
+    my $callback; $callback = sub {
+        my ($data, $headers) = @_;
+        $cv->send;
+    };
+
+    my %get_opt = (
+        on_body => sub {
+            my ($partial, $headers) = @_;
+            $cb->($partial);
+            return 1;
+        },
+    );
+
+    http_request(POST => $uri->as_string, %get_opt, $callback);
+
+    return $cv;
+}
+
 1;
 
 =head1 NAME
 
 Net::Docker - Interface to the Docker API
 
+=head1 SYNOPSIS
+
+    use Net::Docker;
+
+    my $api = Net::Docker->new;
+
+    my $id = $api->create(Image => 'ubuntu', Cmd => ['/bin/bash'], AttachStdin => \1, OpenStdin => \1);
+
+    say $id;
+    $api->start($id);
+
+    my $cv = $api->streaming_logs($id, (stream => 1, stdin => 1, stderr => 1, stdout => 1, logs => 1), sub {
+        my ($log) = @_;
+        print $log;
+    });
+    $cv->recv;
+
+=head1 DESCRIPTION
+
+Perl module for using the Docker Remote API.
+
 =head1 AUTHOR
 
 Peter Stuifzand E<lt>peter@stuifzand.euE<gt>
@@ -180,4 +251,6 @@ it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
+L<http://docker.io>
+
 =cut
